package jms;


import java.util.Hashtable;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.MessageConsumer;
import javax.jms.MessageProducer;
import javax.jms.Session;
import javax.jms.TextMessage;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

public class App {

	public static void main(String[] args) throws NamingException, JMSException {

		final String lOOKUP_CONNECTION_FACTORY_NAME = "lookup.connectionfactory.name";
		final String lOOKUP_DESTINATION_NAME = "lookup.destination.name";

		ConnectionFactory connectionFactory = null;
		Connection connection = null;
		Session session = null;
		MessageProducer producer = null;
		MessageConsumer consumer = null;
		Destination destination = null;
		TextMessage message = null;
		Context context = null;

		try {
			// 创建上下文（默认会从应用的classpath下加载jndi.properties做为环境参数）
			context = new InitialContext();

			// 把环境参数取出来，后面会用到
			Hashtable<String, String> env = (Hashtable<String, String>) context
					.getEnvironment();

			// 查找连接工厂
			connectionFactory = (ConnectionFactory) context.lookup(env
					.get(lOOKUP_CONNECTION_FACTORY_NAME));

			// 查找目标队列
			destination = (Destination) context.lookup(env
					.get(lOOKUP_DESTINATION_NAME));

			// 创建连接
			connection = connectionFactory.createConnection(
					env.get(Context.SECURITY_PRINCIPAL),
					env.get(Context.SECURITY_CREDENTIALS));

			// 创建会话
			session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);

			// 创建生产者(即发送者)
			producer = session.createProducer(destination);

			// 创建消费者(即接收者)
			consumer = session.createConsumer(destination);

			// 开始连接
			connection.start();

			// 发送消息

			message = session.createTextMessage("HELLO,I AM GLAD TO SEE YOU!");

			producer.send(message);

			System.out.println("发送成功!");

	

		} catch (NamingException e) {
			e.printStackTrace();
		} catch (JMSException e) {
			e.printStackTrace();
		} finally {
			// 释放资源
			if (context != null) {
				context.close();
			}

			if (connection != null) {
				connection.close();
			}

		}
	}

}
